@@ -16,12 +16,11 @@
 #   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 #
 """Functions for geometries."""
+
 import math
+from collections.abc import Iterable
 from itertools import groupby
 from itertools import zip_longest
-from typing import Iterable
-from typing import List
-from typing import Tuple
 from typing import Union
 from typing import cast
 
@@ -41,19 +40,20 @@ def signed_area(coords: LineType) -> float:
     Linear time algorithm: http://www.cgafaq.info/wiki/Polygon_Area.
     A value >= 0 indicates a counter-clockwise oriented ring.
     """
+    if len(coords) < 3:  # noqa: PLR2004
+        return 0.0
     xs, ys = map(list, zip(*(coord[:2] for coord in coords)))
     xs.append(xs[1])  # pragma: no mutate
     ys.append(ys[1])  # pragma: no mutate
     return cast(
-        float,
+        "float",
         sum(xs[i] * (ys[i + 1] - ys[i - 1]) for i in range(1, len(coords))) / 2.0,
     )
 
 
-def centroid(coords: LineType) -> Tuple[Point2D, float]:
+def centroid(coords: LineType) -> tuple[Point2D, float]:
     """Calculate the coordinates of the centroid and the area of a LineString."""
-    ans: List[float] = [0, 0]
-
+    ans: list[float] = [0, 0]
     n = len(coords)
     signed_area = 0.0
 
@@ -68,15 +68,18 @@ def centroid(coords: LineType) -> Tuple[Point2D, float]:
         ans[0] += (coord[0] + next_coord[0]) * area
         ans[1] += (coord[1] + next_coord[1]) * area
 
-    ans[0] = (ans[0]) / (3 * signed_area)
-    ans[1] = (ans[1]) / (3 * signed_area)
+    if signed_area == 0 or math.isnan(signed_area):
+        return ((math.nan, math.nan), signed_area)
 
-    return cast(Point2D, tuple(ans)), signed_area / 2.0
+    ans[0] = ans[0] / (3 * signed_area)
+    ans[1] = ans[1] / (3 * signed_area)
+
+    return cast("Point2D", tuple(ans)), signed_area / 2.0
 
 
 def dedupe(coords: LineType) -> LineType:
     """Remove duplicate Points from a LineString."""
-    return cast(LineType, tuple(coord for coord, _count in groupby(coords)))
+    return cast("LineType", tuple(coord for coord, _count in groupby(coords)))
 
 
 def _orientation(p: Point2D, q: Point2D, r: Point2D) -> float:
@@ -93,9 +96,9 @@ def _orientation(p: Point2D, q: Point2D, r: Point2D) -> float:
     return (q[1] - p[1]) * (r[0] - q[0]) - (q[0] - p[0]) * (r[1] - q[1])
 
 
-def _hull(points: Iterable[Point2D]) -> List[Point2D]:
+def _hull(points: Iterable[Point2D]) -> list[Point2D]:
     """Construct the upper/lower hull of a set of points."""
-    stack: List[Point2D] = []
+    stack: list[Point2D] = []
     for p in points:
         while (
             len(stack) >= 2  # noqa: PLR2004
@@ -150,7 +153,7 @@ def compare_coordinates(
         )
     except TypeError:
         try:
-            return math.isclose(a=cast(float, coords), b=cast(float, other))
+            return math.isclose(a=cast("float", coords), b=cast("float", other))
         except TypeError:
             return False
 
@@ -167,13 +170,13 @@ def compare_geo_interface(
             return all(
                 compare_geo_interface(first=g1, second=g2)  # type: ignore [arg-type]
                 for g1, g2 in zip_longest(
-                    first["geometries"],  # type: ignore [typeddict-item]
+                    first["geometries"],
                     second["geometries"],  # type: ignore [typeddict-item]
                     fillvalue={"type": None, "coordinates": ()},
                 )
             )
         return compare_coordinates(
-            coords=first["coordinates"],  # type: ignore [typeddict-item]
+            coords=first["coordinates"],
             other=second["coordinates"],  # type: ignore [typeddict-item]
         )
     except KeyError:
@@ -197,11 +200,11 @@ def move_coordinate(
     """
     if len(coordinate) < len(move_by):
         return cast(
-            PointType,
+            "PointType",
             tuple(c + m for c, m in zip_longest(coordinate, move_by, fillvalue=0)),
         )
 
-    return cast(PointType, tuple(c + m for c, m in zip(coordinate, move_by)))
+    return cast("PointType", tuple(c + m for c, m in zip(coordinate, move_by)))
 
 
 def move_coordinates(
@@ -220,11 +223,15 @@ def move_coordinates(
     >>> move_coordinates(((0, 0), (-1, 1)), (-1, 1, 0))
     ((-1, 1, 0), (-2, 2, 0))
     """
+    if not coordinates:
+        return coordinates
     if isinstance(coordinates[0], (int, float)):
-        return move_coordinate(cast(PointType, coordinates), move_by)
+        return move_coordinate(cast("PointType", coordinates), move_by)
     return cast(
-        CoordinatesType,
-        tuple(move_coordinates(cast(CoordinatesType, c), move_by) for c in coordinates),
+        "CoordinatesType",
+        tuple(
+            move_coordinates(cast("CoordinatesType", c), move_by) for c in coordinates
+        ),
     )
 
 
@@ -237,14 +244,13 @@ def move_geo_interface(
         return {
             "type": "GeometryCollection",
             "geometries": tuple(
-                move_geo_interface(g, move_by)
-                for g in interface["geometries"]  # type: ignore [typeddict-item]
+                move_geo_interface(g, move_by) for g in interface["geometries"]
             ),
         }
     return {
         "type": interface["type"],
         "coordinates": move_coordinates(
-            interface["coordinates"],  # type: ignore [typeddict-item, arg-type]
+            interface["coordinates"],  # type: ignore [arg-type]
             move_by,
         ),
     }
